@@ -68,12 +68,7 @@ class MyPyllantDataClass:
 
         for k, v in data.items():
             if v is not None and k in datetime_fields and timezone is not None:
-                if v.endswith("Z"):
-                    # Some dates are returned as "2024-01-01T00:00:00Z" without timezone information
-                    data[k] = datetime_parse(v, timezone)
-                else:
-                    # ... and some are ISO formatted with timezone information
-                    data[k] = datetime.datetime.fromisoformat(v)
+                data[k] = datetime_parse(v, timezone)
 
         if extra_fields:
             data["extra_fields"] = {f: data[f] for f in extra_fields}
@@ -552,7 +547,9 @@ class DomesticHotWater(MyPyllantDataClass):
     system_id: str
     index: int
     control_identifier: ControlIdentifier
-    current_special_function: DHWCurrentSpecialFunction | DHWCurrentSpecialFunctionVRC700
+    current_special_function: (
+        DHWCurrentSpecialFunction | DHWCurrentSpecialFunctionVRC700
+    )
     max_setpoint: float
     min_setpoint: float
     operation_mode_dhw: DHWOperationMode | DHWOperationModeVRC700
@@ -597,7 +594,9 @@ class Ventilation(MyPyllantDataClass):
     control_identifier: ControlIdentifier
     maximum_day_fan_stage: int
     maximum_night_fan_stage: int
-    operation_mode_ventilation: VentilationOperationMode | VentilationOperationModeVRC700
+    operation_mode_ventilation: (
+        VentilationOperationMode | VentilationOperationModeVRC700
+    )
     time_program_ventilation: dict
 
     @classmethod
