@@ -29,10 +29,8 @@ async def test_find_countries(mocker) -> None:
     with mock.patch("requests.head") as patched_head:
         patched_head.return_value.status_code = 200
         assert list(countries_with_realm("vaillant")) == [
-            ("bosniaandherzegovina", "Bosnia and Herzegovina"),
             ("germany", "Germany"),
             ("kosovo", "Kosovo"),
-            ("northmacedonia", "North Macedonia"),
         ]
         patched_head.return_value.status_code = 404
         assert list(countries_with_realm("vaillant")) == []
